jQuery(document).ready(function($) {
    // Fix category counts
    $('#genex-fix-counts').on('click', function() {
        $('#genex-counts-message').hide();
        
        // Show a loading indicator
        $(this).prop('disabled', true).text('Updating...');
        
        $.ajax({
            url: genex_detach_restore.ajax_url,
            type: 'POST',
            data: {
                action: 'genex_fix_category_counts',
                nonce: genex_detach_restore.nonce
            },
            success: function(response) {
                // Re-enable the button
                $('#genex-fix-counts').prop('disabled', false).text('Fix Category Counts');
                
                if (response.success) {
                    $('#genex-counts-message')
                        .removeClass('notice-error')
                        .addClass('notice-success')
                        .html('<p>' + response.data.message + '</p>')
                        .show();
                } else {
                    $('#genex-counts-message')
                        .removeClass('notice-success')
                        .addClass('notice-error')
                        .html('<p>' + response.data.message + '</p>')
                        .show();
                }
            },
            error: function() {
                // Re-enable the button
                $('#genex-fix-counts').prop('disabled', false).text('Fix Category Counts');
                
                $('#genex-counts-message')
                    .removeClass('notice-success')
                    .addClass('notice-error')
                    .html('<p>An error occurred while updating category counts.</p>')
                    .show();
            }
        });
    });	
	// Detach all products
    $('#genex-detach-all').on('click', function() {
        if (!confirm(genex_detach_restore.confirm_detach)) {
            return;
        }
        
        // Show progress container
        $('#genex-progress-container').show();
        $('#genex-progress-text').text(genex_detach_restore.backup_text);
        $('#genex-progress-bar').css('width', '0%');
        $('#genex-message').hide();
        
        // Step 1: Backup category relations
        $.ajax({
            url: genex_detach_restore.ajax_url,
            type: 'POST',
            data: {
                action: 'genex_backup_category_relations',
                nonce: genex_detach_restore.nonce
            },
            success: function(response) {
                if (response.success) {
                    // Step 2: Detach products
                    $('#genex-progress-text').text(genex_detach_restore.detach_text);
                    $('#genex-progress-bar').css('width', '0%');
                    
                    detachProducts(response.data.backup_id, 0);
                } else {
                    showError(response.data.message);
                }
            },
            error: function() {
                showError('An error occurred while backing up categories.');
            }
        });
    });
    
    // Restore backup
    $(document).on('click', '.genex-restore-backup', function() {
        var backupId = $(this).data('backup-id');
        
        if (!confirm(genex_detach_restore.confirm_restore)) {
            return;
        }
        
        // Show progress container
        $('#genex-progress-container').show();
        $('#genex-progress-text').text(genex_detach_restore.restore_text);
        $('#genex-progress-bar').css('width', '0%');
        $('#genex-message').hide();
        
        restoreBackup(backupId, 0);
    });
    
    // Detach products function (processes in batches)
    function detachProducts(backupId, offset) {
        $.ajax({
            url: genex_detach_restore.ajax_url,
            type: 'POST',
            data: {
                action: 'genex_detach_products',
                nonce: genex_detach_restore.nonce,
                backup_id: backupId,
                offset: offset
            },
            success: function(response) {
                if (response.success) {
                    if (response.data.done) {
                        // All products detached
                        $('#genex-progress-bar').css('width', '100%');
                        showSuccess(response.data.message);
                        
                        // Reload page to update backup list
                        setTimeout(function() {
                            location.reload();
                        }, 2000);
                    } else {
                        // Update progress
                        $('#genex-progress-bar').css('width', response.data.progress + '%');
                        $('#genex-progress-text').text(response.data.message);
                        
                        // Process next batch
                        detachProducts(backupId, response.data.offset);
                    }
                } else {
                    showError(response.data.message);
                }
            },
            error: function() {
                showError('An error occurred while detaching products from categories.');
            }
        });
    }
    
    // Restore backup function (processes in batches)
    function restoreBackup(backupId, offset) {
        $.ajax({
            url: genex_detach_restore.ajax_url,
            type: 'POST',
            data: {
                action: 'genex_restore_backup',
                nonce: genex_detach_restore.nonce,
                backup_id: backupId,
                offset: offset
            },
            success: function(response) {
                if (response.success) {
                    if (response.data.done) {
                        // Restore completed
                        $('#genex-progress-bar').css('width', '100%');
                        showSuccess(response.data.message);
                        
                        // Reload page to update backup list
                        setTimeout(function() {
                            location.reload();
                        }, 2000);
                    } else {
                        // Update progress
                        $('#genex-progress-bar').css('width', response.data.progress + '%');
                        $('#genex-progress-text').text(response.data.message);
                        
                        // Process next batch
                        restoreBackup(backupId, response.data.offset);
                    }
                } else {
                    showError(response.data.message);
                }
            },
            error: function() {
                showError('An error occurred while restoring the backup.');
            }
        });
    }
    
    // Show success message
    function showSuccess(message) {
        $('#genex-message')
            .removeClass('notice-error notice-warning notice-info')
            .addClass('notice-success')
            .html('<p>' + message + '</p>')
            .show();
    }
    
    // Show error message
    function showError(message) {
        $('#genex-progress-bar').css('width', '0%');
        $('#genex-message')
            .removeClass('notice-success notice-warning notice-info')
            .addClass('notice-error')
            .html('<p>' + message + '</p>')
            .show();
    }
});